searchData={"items":[{"type":"module","title":"DigitalToken","doc":"Functions to validate, search and retrieve digital token\ndata sourced from the [DTIF registry](https://dtif.org).","ref":"DigitalToken.html"},{"type":"function","title":"DigitalToken.get_token/1","doc":"Returns the registry data for a given token\nidentifier.","ref":"DigitalToken.html#get_token/1"},{"type":"function","title":"Arguments - DigitalToken.get_token/1","doc":"* `id` is any token identifier or short name","ref":"DigitalToken.html#get_token/1-arguments"},{"type":"function","title":"Returns - DigitalToken.get_token/1","doc":"* `{:ok, registry_data}` or\n\n* `{:error, {exception, id}}`","ref":"DigitalToken.html#get_token/1-returns"},{"type":"function","title":"Example - DigitalToken.get_token/1","doc":"DigitalToken.get_token(\"BTC\")\n    #=> {:ok,\n     %DigitalToken{\n       header: %{\n         dlt_type: :blockchain,\n         dti: \"4H95J0R2X\",\n         dti_type: :native,\n         template_version: #Version<1.0.0>\n       },\n       informative: %{\n         long_name: \"Bitcoin\",\n         public_distributed_ledger_indication: false,\n         short_names: [\"BTC\", \"XBT\"],\n         unit_multiplier: 100000000,\n         url: \"https://github.com/bitcoin/bitcoin\"\n       },\n       metadata: %{\n         .....","ref":"DigitalToken.html#get_token/1-example"},{"type":"function","title":"DigitalToken.get_token!/1","doc":"Returns the registry data for a given token\nidentifier.","ref":"DigitalToken.html#get_token!/1"},{"type":"function","title":"Arguments - DigitalToken.get_token!/1","doc":"* `id` is any token identifier or short name","ref":"DigitalToken.html#get_token!/1-arguments"},{"type":"function","title":"Returns - DigitalToken.get_token!/1","doc":"* `registry_data` or\n\n* raises an exception","ref":"DigitalToken.html#get_token!/1-returns"},{"type":"function","title":"Example - DigitalToken.get_token!/1","doc":"DigitalToken.get_token(\"BTC\")\n    #=> %DigitalToken{\n       header: %{\n         dlt_type: :blockchain,\n         dti: \"4H95J0R2X\",\n         dti_type: :native,\n         template_version: #Version<1.0.0>\n       },\n       informative: %{\n         long_name: \"Bitcoin\",\n         public_distributed_ledger_indication: false,\n         short_names: [\"BTC\", \"XBT\"],\n         unit_multiplier: 100000000,\n         url: \"https://github.com/bitcoin/bitcoin\"\n       },\n       metadata: %{\n         .....","ref":"DigitalToken.html#get_token!/1-example"},{"type":"macro","title":"DigitalToken.is_digital_token/1","doc":"","ref":"DigitalToken.html#is_digital_token/1"},{"type":"function","title":"DigitalToken.long_name/1","doc":"Returns the long name of a digital token.","ref":"DigitalToken.html#long_name/1"},{"type":"function","title":"Arguments - DigitalToken.long_name/1","doc":"* `token_id` is any valid digital token identifier.","ref":"DigitalToken.html#long_name/1-arguments"},{"type":"function","title":"Returns - DigitalToken.long_name/1","doc":"* `{:ok, long_name}` where `long_name` is the token's\n  registered name.\n\n* `{:error, {exception, reason}}`","ref":"DigitalToken.html#long_name/1-returns"},{"type":"function","title":"Examples - DigitalToken.long_name/1","doc":"iex> DigitalToken.long_name \"BTC\"\n    {:ok, \"Bitcoin\"}\n\n    iex> DigitalToken.long_name \"4H95J0R2X\"\n    {:ok, \"Bitcoin\"}\n\n    iex> DigitalToken.long_name \"W0HBX7RC4\"\n    {:ok, \"Terra Classic\"}","ref":"DigitalToken.html#long_name/1-examples"},{"type":"function","title":"DigitalToken.short_name/1","doc":"Returns the short name of a digital token.","ref":"DigitalToken.html#short_name/1"},{"type":"function","title":"Arguments - DigitalToken.short_name/1","doc":"* `token_id` is any valid digital token identifier.","ref":"DigitalToken.html#short_name/1-arguments"},{"type":"function","title":"Returns - DigitalToken.short_name/1","doc":"* `{:ok, short_name}` where `short_name` is either\n  the first short name in `token.informative.short_names` or\n  the token long name if there are no short names.\n\n* `{:error, {exception, reason}}`","ref":"DigitalToken.html#short_name/1-returns"},{"type":"function","title":"Examples - DigitalToken.short_name/1","doc":"iex> DigitalToken.short_name \"BTC\"\n    {:ok, \"BTC\"}\n\n    iex> DigitalToken.short_name \"4H95J0R2X\"\n    {:ok, \"BTC\"}\n\n    iex> DigitalToken.short_name \"W0HBX7RC4\"\n    {:ok, \"Terra Classic\"}","ref":"DigitalToken.html#short_name/1-examples"},{"type":"function","title":"DigitalToken.short_names/0","doc":"Returns a mapping of digital token short\nnames to digital token identifiers.","ref":"DigitalToken.html#short_names/0"},{"type":"function","title":"DigitalToken.symbol/2","doc":"Returns a currency symbol used in number formatting.","ref":"DigitalToken.html#symbol/2"},{"type":"function","title":"Arguments - DigitalToken.symbol/2","doc":"* `token_id` is any valid digital token identifier.\n\n* `style` is a number in the range `1` to `4` as follows:\n    * `1` is the token's symbol, if it exists\n    * `2` is the token's short name as a proxy for a currency code\n    * `3` is the token's long name\n    * `4` is the token's symbol as a proxy for a narrow currency symbol","ref":"DigitalToken.html#symbol/2-arguments"},{"type":"function","title":"Returns - DigitalToken.symbol/2","doc":"* `{:ok, symbol}` or\n\n* `{:error, {exception, reason}}`","ref":"DigitalToken.html#symbol/2-returns"},{"type":"function","title":"Examples - DigitalToken.symbol/2","doc":"iex> DigitalToken.symbol \"BTC\", 1\n    {:ok, \"₿\"}\n\n    iex> DigitalToken.symbol \"BTC\", 2\n    {:ok, \"BTC\"}\n\n    iex> DigitalToken.symbol \"BTC\", 3\n    {:ok, \"Bitcoin\"}\n\n    iex> DigitalToken.symbol \"BTC\", 4\n    {:ok, \"₿\"}\n\n    iex> DigitalToken.symbol \"ETH\", 4\n    {:ok, \"Ξ\"}\n\n    iex> DigitalToken.symbol \"DOGE\", 4\n    {:ok, \"Ð\"}\n\n    iex> DigitalToken.symbol \"DODGY\", 4\n    {:error, {DigitalToken.UnknownTokenError, \"DODGY\"}}","ref":"DigitalToken.html#symbol/2-examples"},{"type":"function","title":"DigitalToken.symbols/0","doc":"Returns a mapping of digital token identifiers\nnames to a currency symbol.","ref":"DigitalToken.html#symbols/0"},{"type":"function","title":"DigitalToken.tokens/0","doc":"Returns a map of the digital tokens in the\n[dtif registry](https://dtif.org).","ref":"DigitalToken.html#tokens/0"},{"type":"function","title":"DigitalToken.validate_token/1","doc":"Validates a token identifier or short name\nand returns the token identifier or an error.","ref":"DigitalToken.html#validate_token/1"},{"type":"function","title":"Arguments - DigitalToken.validate_token/1","doc":"* `id` is any token identifier or short name","ref":"DigitalToken.html#validate_token/1-arguments"},{"type":"function","title":"Returns - DigitalToken.validate_token/1","doc":"* `{:ok, token_id}` or\n\n* `{:error, {exception, id}}`","ref":"DigitalToken.html#validate_token/1-returns"},{"type":"function","title":"Example - DigitalToken.validate_token/1","doc":"iex> DigitalToken.validate_token(\"BTC\")\n    {:ok, \"4H95J0R2X\"}\n\n    iex> DigitalToken.validate_token(\"Bitcoin\")\n    {:ok, \"4H95J0R2X\"}\n\n    iex> DigitalToken.validate_token \"4H95J0R2X\"\n    {:ok, \"4H95J0R2X\"}\n\n    iex> DigitalToken.validate_token(\"Nothing\")\n    {:error, {DigitalToken.UnknownTokenError, \"Nothing\"}}","ref":"DigitalToken.html#validate_token/1-example"},{"type":"type","title":"DigitalToken.short_name/0","doc":"A digital token may have zero or more short\nnames associated with it. They are arbitrary\nstrings, usually three or four characters in\nlength. For example \"BTC\", \"ETH\" and \"DOGE\".","ref":"DigitalToken.html#t:short_name/0"},{"type":"type","title":"DigitalToken.short_name_map/0","doc":"A mapping from a short name to token\nidentifier.","ref":"DigitalToken.html#t:short_name_map/0"},{"type":"type","title":"DigitalToken.symbol_map/0","doc":"A mapping of digital token identifiers\nto a currency symbol for that token.","ref":"DigitalToken.html#t:symbol_map/0"},{"type":"type","title":"DigitalToken.t/0","doc":"The structure of data matching that hosted in\nthe [DTIF registry](https://dtif.org)/","ref":"DigitalToken.html#t:t/0"},{"type":"type","title":"DigitalToken.token_id/0","doc":"token_id is a random 9-character\nstring defined by the [dtif registry](https://dtif.org)\nthat uniquely identifies a digital token.","ref":"DigitalToken.html#t:token_id/0"},{"type":"type","title":"DigitalToken.token_map/0","doc":"A mapping of digital token identifiers\nto the registry data for that token.","ref":"DigitalToken.html#t:token_map/0"},{"type":"type","title":"DigitalToken.token_type/0","doc":"The type of a token","ref":"DigitalToken.html#t:token_type/0"},{"type":"module","title":"DigitalToken.Config","doc":"","ref":"DigitalToken.Config.html"},{"type":"function","title":"DigitalToken.Config.json_library/0","doc":"Return the configured json lib","ref":"DigitalToken.Config.html#json_library/0"},{"type":"task","title":"mix digital_token.registry.update","doc":"Updates the digital token registry data.","ref":"Mix.Tasks.DigitalToken.Registry.Update.html"},{"type":"task","title":"mix digital_token.symbols.update","doc":"Updates the digital token symbols data.\n\nData is copied from [Crypto Currency Symbols](https://github.com/yonilevy/crypto-currency-symbols).","ref":"Mix.Tasks.DigitalToken.Symbols.Update.html"},{"type":"exception","title":"DigitalToken.UnknownTokenError","doc":"Exception raised when a digital token is unknown.","ref":"DigitalToken.UnknownTokenError.html"},{"type":"extras","title":"Digital Token","doc":"# Digital Token\n\n[ISO 24165](https://www.iso.org/standard/80601.html) introduces a common language for digital currencies. Up until now, digital currencies (\"crypto\") have been an uncomfortable fit into the world of currencies which are governed by [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217).\n\n`ISO 4217` does allow for private use currencies, however in common use several crypto currencies use unnoficial `ISO 4217` codes that clash with the standard.\n\nThe introduction of `ISO 24165` (and is relationship to [ISO 20022](https://www.iso20022.org)) creates a framework for the identification and standardisation of digital tokens.\n\nIn addition, the [Digital Token Identification Foundation (DTIF)](https://dtif.org) has been formed to operate a [registry](https://dtif.org/token-registry-search/) of tokens with [downloadable data](https://dtif.org/download-dti-registry/) making it easy to access and integrate the data into applications.\n\nThis library provides a means to download and access the digital token registry. One application is the upcoming integration of `digital_token` into [ex_money](https://github.com/kipcole9/money) providing money operations on both ISO 4217 currencies and ISO 24165 digital tokens.","ref":"readme.html"},{"type":"extras","title":"Digital Token Identifier Format - Digital Token","doc":"The basic number is eight characters (alphanumeric) in length but excludes vowels (A, E, I, O, U) and the letter Y, and zero shall not be the first character.  A ninth character is added and is calculated as a checksum.","ref":"readme.html#digital-token-identifier-format"},{"type":"extras","title":"Non-ISO 4217 cryptocurrency codes - Digital Token","doc":"The following are examples of commonly-used but non-compliant `ISO 4217` currency codes. This, plus the inherent flux in the number of digital currencies gave rise to `ISO 24165`.\n\n\nUnofficial code | Digits | Currency | Notes\n---------- | --- | ------------- | ---------\nADA       | 6 | Ada\t        | ADA conflicts with ISO 4217, because AD stands for Andorra.\nBNB       | 8 | Binance\tBNB | BNB conflicts with ISO 4217, because BN stands for Brunei Darussalam.\nBSV       | 8 | Bitcoin SV\t| BSV conflicts with ISO 4217, because BS stands for Bahamas.\nBTC, XBT  | 8 |\tBitcoin     |\tXBT conflicts with ISO 4217, because BT stands for Bhutan.\nDASH      |\t8\t| Dash\t      | DASH is of non-standard length.\nDOGE      |\t4 |\tDogecoin\t  | DOGE is of non-standard length.\nETH       | 18|\tEthereum\t  | ETH conflicts with ISO 4217, because ET stands for Ethiopia.\nLTC       | 8 |\tLitecoin\t  | LTC conflicts with ISO 4217, because LT stands for Lithuania.","ref":"readme.html#non-iso-4217-cryptocurrency-codes"},{"type":"extras","title":"Installation - Digital Token","doc":"The package can be installed by adding `digital_token` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:digital_token, \"~> 0.2.0\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Digital Token","doc":"`DigitalToken` requires that a JSON library be configuration that provides a `decode!/1` function. Common libraries sucn as [poison](https://hex.pm/packages/poison), [jason](https://hex.pm/packages/jason) and [jsonrs](https://hex.pm/packages/jsonrs) are good examples.\n\nA JSON library can be configured on `config.exs` like this:\n```elixir\nconfig :digital_token,\n  json_library: Jason\n```\nNote that the configuration parameter is the module upon which the `decode!/1` function is available.\n\nIf no configuration is set, `DigitalToken` will attempt to use `Jason`, `Poison`, the JSON library configuration for [ecto](https://hex.pm/packages/ecto) or the JSON library configured for [Phoenix](https://hex.pm/packages/phoenix).","ref":"readme.html#configuration"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Digital Token 1.0.0 - Changelog","doc":"This is the changelog for Digital Token version 1.0.0 released on September 6th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/digital_token/tags)","ref":"changelog.html#digital-token-1-0-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix parsing error on some tokens from the updated registry.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Use the erlang `:json` module as a candidate JSON decoder if the underlying OTP release supports it (>= OTP 27).  This support also requires at least `cldr_utils` version 2.28.2.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Digital Token 0.6.0 - Changelog","doc":"This is the changelog for Digital Token version 0.6.0 released on July 8th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/digital_token/tags)","ref":"changelog.html#digital-token-0-6-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove checking Phoenix and Ecto json_library configurations.  Ecto no longer configures its `:json_library` in `config.exs` and checking for Phoenix configuration can cause config failures when [building in Docker](https://github.com/elixir-cldr/cldr/issues/208).\n\n* Sort the short names for a token by their length so that the standard short name is the shortest one.\n\n* Fix code that made an implicit assumption about map order.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to the latest toekn registry and symbol registry.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Digital Token 0.5.0 - Changelog","doc":"This is the changelog for Digital Token version 0.5.0 released on June 22nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/digital_token/tags)","ref":"changelog.html#digital-token-0-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Make the JSON library configurable. Like `ex_cldr` it will also attempt to use the JSON library configured for `ex_cldr`, `ecto`, `phoenix` or if otherwise configured `Jason` or `Poison`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Digital Token 0.4.0 - Changelog","doc":"This is the changelog for Digital Token version 0.4.0 released on May 20th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/digital_token/tags)","ref":"changelog.html#digital-token-0-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Parse and structure the downloaded digital token registry and digital token symbols at download time rather than compile time. This reduces the compile time significantly.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Digital Token 0.3.0 - Changelog","doc":"This is the changelog for Digital Token version 0.3.0 released on May 14th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/digital_token/tags)","ref":"changelog.html#digital-token-0-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `DigitalToken.short_name/1` to return the short name of the digital token. This is analogous to the currency code for a currency.\n\n* Add `DigitalToken.long_name/1` to return the long name of the digital token. This is analogous to the name of a currency.\n\n* Add `DigitalToken.symbol/2` to return a \"currency\" symbol for a digital token that will be used for number formatting in [ex_cldr_numbers](https://github.com/elixir-cldr/cldr_numbers) and [ex_money](https://github.com/kipcole9/money).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Digital Token 0.2.0 - Changelog","doc":"This is the changelog for Digital Token version 0.2.0 released on May 9th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/digital_token/tags)","ref":"changelog.html#digital-token-0-2-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Return only the token id from `DigitalToken.validate_token/1` when the argument is already a valid token identifier.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Digital Token 0.1.0 - Changelog","doc":"This is the changelog for Digital Token version 0.1.0 released on May 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/digital_token/tags)","ref":"changelog.html#digital-token-0-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Initial release","ref":"changelog.html#enhancements"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2022 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}